#[non_exhaustive]pub struct BoxShowResponse {
pub id: i64,
pub kind: String,
pub name: String,
pub app_url: Option<String>,
pub url: Option<String>,
pub signed_stream_name: Option<String>,
pub posting_changes_url: Option<String>,
pub updates_channels: Option<Vec<UpdatesChannel>>,
pub next_history_url: Option<String>,
pub next_incremental_sync_url: Option<String>,
pub postings: Option<Vec<Posting>>,
}Expand description
BoxShowResponse — box detail with postings.
The API can return fields at root level or nested under a box key.
SDK response decoders normalize the nested variant to flat before decoding.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: i64kind: Stringname: Stringapp_url: Option<String>url: Option<String>signed_stream_name: Option<String>posting_changes_url: Option<String>updates_channels: Option<Vec<UpdatesChannel>>next_history_url: Option<String>next_incremental_sync_url: Option<String>postings: Option<Vec<Posting>>Trait Implementations
Sourceimpl Clone for BoxShowResponse
impl Clone for BoxShowResponse
Sourcefn clone(&self) -> BoxShowResponse
fn clone(&self) -> BoxShowResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BoxShowResponse
impl Debug for BoxShowResponse
Sourceimpl Default for BoxShowResponse
impl Default for BoxShowResponse
Sourcefn default() -> BoxShowResponse
fn default() -> BoxShowResponse
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BoxShowResponse
impl<'de> Deserialize<'de> for BoxShowResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for BoxShowResponse
impl PartialEq for BoxShowResponse
Sourceimpl Serialize for BoxShowResponse
impl Serialize for BoxShowResponse
impl StructuralPartialEq for BoxShowResponse