#[non_exhaustive]pub struct BulkReplyDelivery {
pub id: i64,
pub entries_count: i32,
pub delayed: bool,
pub undo_send_url: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: i64entries_count: i32delayed: boolTrue while the send is held open for undo.
undo_send_url: Option<String>Where to POST to call the replies back, present only while delayed.