#[non_exhaustive]pub struct BulkReplyDraft {
pub content: String,
pub entries: Vec<BulkReplyEntry>,
}Expand description
The reply as HEY would send it: the prefilled content and the entries it goes to.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.content: StringThe prefilled body — the name tag when every thread is on the same account.
entries: Vec<BulkReplyEntry>Trait Implementations
Sourceimpl Clone for BulkReplyDraft
impl Clone for BulkReplyDraft
Sourcefn clone(&self) -> BulkReplyDraft
fn clone(&self) -> BulkReplyDraft
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BulkReplyDraft
impl Debug for BulkReplyDraft
Sourceimpl Default for BulkReplyDraft
impl Default for BulkReplyDraft
Sourcefn default() -> BulkReplyDraft
fn default() -> BulkReplyDraft
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BulkReplyDraft
impl<'de> Deserialize<'de> for BulkReplyDraft
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for BulkReplyDraft
impl PartialEq for BulkReplyDraft
Sourceimpl Serialize for BulkReplyDraft
impl Serialize for BulkReplyDraft
impl StructuralPartialEq for BulkReplyDraft