#[non_exhaustive]pub struct Clearance {
pub id: i64,
pub status: Option<String>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
pub petitioner: Option<Contact>,
pub most_recent_entry: Option<Entry>,
}Expand description
Clearance — screening status for a contact
petitioner and most_recent_entry are only filled in by the Screener reads. The contact reads answer a clearance with nothing but its id and status.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: i64status: Option<String>created_at: Option<DateTime>ISO 8601 date-time timestamp (overrides restJson1 epoch-seconds default)
updated_at: Option<DateTime>ISO 8601 date-time timestamp (overrides restJson1 epoch-seconds default)
petitioner: Option<Contact>most_recent_entry: Option<Entry>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Clearance
impl<'de> Deserialize<'de> for Clearance
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for Clearance