CreateBulkReplyResponseContent

Type Alias CreateBulkReplyResponseContent 

pub type CreateBulkReplyResponseContent = BulkReplyDelivery;

Aliased Type

pub struct CreateBulkReplyResponseContent {
    pub id: i64,
    pub entries_count: i32,
    pub delayed: bool,
    pub undo_send_url: Option<String>,
}

Fields

id: i64entries_count: i32delayed: bool

True while the send is held open for undo.

undo_send_url: Option<String>

Where to POST to call the replies back, present only while delayed.